adj2nlapl: Generate a normalized graph Laplacian

View source: R/gelnet.R

adj2nlaplR Documentation

Generate a normalized graph Laplacian

Description

Generates a normalized graph Laplacian from the graph adjacency matrix.

Usage

adj2nlapl(A)

Arguments

A

n-by-n adjacency matrix for a graph with n nodes

Details

A normalized graph Laplacian is defined as: l_{i,j} = 1 , if i = j ; l_{i,j} = - 1 / \sqrt{ deg(v_i) deg(v_j) } , if i \neq j and v_i is adjacent to v_j; and l_{i,j} = 0 , otherwise

Value

The n-by-n Laplacian matrix of the graph

See Also

adj2nlapl


gelnet documentation built on July 22, 2026, 9:07 a.m.