| gelnet.oneclass.obj | R Documentation |
Evaluates the one-class objective function value for a given model See details.
gelnet.oneclass.obj(
w,
X,
l1,
l2,
d = rep(1, ncol(X)),
P = diag(ncol(X)),
m = rep(0, ncol(X))
)
w |
p-by-1 vector of model weights |
X |
n-by-p matrix of n samples in p dimensions |
l1 |
L1-norm penalty scaling factor |
l2 |
L2-norm penalty scaling factor |
d |
p-by-1 vector of feature weights |
P |
p-by-p feature-feature penalty matrix |
m |
p-by-1 vector of translation coefficients |
Computes the objective function value according to
-\frac{1}{n} \sum_i s_i - \log( 1 + \exp(s_i) ) + R(w)
where
s_i = w^T x_i
R(w) = \lambda_1 \sum_j d_j |w_j| + \frac{\lambda_2}{2} (w-m)^T P (w-m)
The objective function value.
gelnet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.