Generates a graph Laplacian from the graph adjacency matrix.
Usage
adj2lapl(A)
Value
The n-by-n Laplacian matrix of the graph
Arguments
A
n-by-n adjacency matrix for a graph with n nodes
Details
A graph Laplacian is defined as:
\( l_{i,j} = deg( v_i ) \), if \( i = j \);
\( l_{i,j} = -1 \), if \( i \neq j \) and \(v_i\) is adjacent to \(v_j\);
and \( l_{i,j} = 0 \), otherwise