| adj2nlapl | R Documentation |
Generates a normalized graph Laplacian from the graph adjacency matrix.
adj2nlapl(A)
A |
n-by-n adjacency matrix for a graph with n nodes |
A normalized graph Laplacian is defined as:
l_{i,j} = 1 , if i = j ;
l_{i,j} = - 1 / \sqrt{ deg(v_i) deg(v_j) } , if i \neq j and v_i is adjacent to v_j;
and l_{i,j} = 0 , otherwise
The n-by-n Laplacian matrix of the graph
adj2nlapl
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.